@@ -517,10 +517,10 @@ class ProviderStatus(object):
 
 class Analytics(object):
 
-    def __init__(self, inputs=None, config_file=None, region=None, env=None, key=None, username=None, password=None, jwt=None):
+    def __init__(self, inputs=None, config_file=None, region=None, env=None, key=None, username=None, password=None, jwt=None, verify=True):
         if inputs is None:
             inputs = {}
-        self.__config = load_config(config_file=config_file, region=region, env=env, key=key, username=username, password=password, jwt=jwt)
+        self.__config = load_config(config_file=config_file, region=region, env=env, key=key, username=username, password=password, jwt=jwt, verify=verify)
         self.__key = self.__config.get("API_KEY")
         self.__prefix = True
         self.__inputs = inputs
@@ -732,12 +732,12 @@ class Analytics(object):
         return appended_dframe[sorted_columns]
 
     # Easy-to-use frontend to enrich, enrich_wait, and enrich_download
-    def enrich_and_download(self, providers, inputs=None, hosted_input=None, validate=True, all_updates=False, fixed_list_size=1):
+    def enrich_and_download(self, providers_or_channel_id, inputs=None, hosted_input=None, validate=True, all_updates=False, fixed_list_size=1):
         """
         Augments your input data with results from our data providers.
         This is the main entry point to the Demyst data platform.
         """
-        id = self.enrich(providers,
+        id = self.enrich(providers_or_channel_id,
                          inputs=inputs,
                          hosted_input=hosted_input,
                          validate=validate,
@@ -745,29 +745,45 @@ class Analytics(object):
                          fixed_list_size=fixed_list_size)
         return self.enrich_download(id)
 
-    def enrich(self, providers, inputs=None, hosted_input=None, validate=True, all_updates=False, fixed_list_size=1):
+    def enrich(self, providers_or_channel_id, inputs=None, hosted_input=None, validate=True, all_updates=False, fixed_list_size=1):
         """
         enrich() is the lower-level (compared to enrich_and_download())
         workhorse that lets you kick off an enrichment job asynchronously.
         """
+        if isinstance(providers_or_channel_id, list):
+            providers = providers_or_channel_id
+            channel_id = None
+        else:
+            providers = None
+            channel_id = providers_or_channel_id
+
+        limit = 20
+        if providers and len(providers) > limit:
+            raise RuntimeError("Only " + str(limit) + " providers are allowed.")
+
         if hosted_input:
             inputs = self.input_file(hosted_input)
-        limit = 20
-        if len(providers) > limit:
-            raise RuntimeError("Only " + str(limit) + " providers are allowed.")
-        provider_names = self.__providers_to_provider_names(providers)
-        self.__check_provider_names(provider_names)
-        print("Starting enrichment...")
+
         if len(inputs) == 0:
             raise RuntimeError("Inputs dataframe is empty")
+
         inputs = self.__stringify_dframe(inputs)
-        if (validate):
+
+        if providers:
+            provider_names = self.__providers_to_provider_names(providers)
+            self.__check_provider_names(provider_names)
+
+        print("Starting enrichment...")
+
+        if (providers and validate):
             if (not self.__validate_providers(provider_names, inputs)):
                 raise RuntimeError("Validation failed")
+
         fd, temp_path = tempfile.mkstemp()
+
         try:
             inputs.to_csv(temp_path, index=False, header=False, quoting=csv.QUOTE_ALL)
-            return self.__enrich_csv(providers, temp_path, list(inputs), all_updates, fixed_list_size)
+            return self.__enrich_csv(temp_path, list(inputs), all_updates, fixed_list_size, providers, channel_id)
         finally:
             os.close(fd)
             try:
@@ -784,23 +800,29 @@ class Analytics(object):
                 return p["name"]
         return [provider_to_provider_name(p) for p in providers]
 
-    def __enrich_csv(self, providers, csv_file, columns, all_updates, fixed_list_size):
+    def __enrich_csv(self, csv_file, columns, all_updates, fixed_list_size, providers=None, channel_id=None):
         num_rows = self.__count_lines_in_file(csv_file)
-        self.__abort_if_not_enough_caps(self.__providers_to_provider_names(providers), num_rows)
+
+        # TODO - should check this for the channel too, but idk how
+        if providers:
+            self.__abort_if_not_enough_caps(self.__providers_to_provider_names(providers), num_rows)
+
         region_id = self.__find_region_id(self.__config.get("REGION"))
         dict = self.__get_presigned_url_and_s3_object_key(region_id)
         url = dict["presigned_url"]
         s3_key = dict["s3_object_key"]
         self.__upload_file_to_presigned_url(csv_file, url)
         input_id = self.__create_batch(csv_file, s3_key, columns, region_id, num_rows)
-        run_batch_id = self.__run_batch(providers, input_id, region_id, all_updates, fixed_list_size)
+
+        run_batch_id = self.__run_batch(input_id, region_id, all_updates, fixed_list_size, providers, channel_id)
+
         print("Enrich Job ID: " + str(run_batch_id))
         return run_batch_id
 
     def __upload_file_to_presigned_url(self, csv_file, url):
         #print("Uploading data...")
         with open(csv_file, "rb") as f:
-            res = requests.put(url, data=f)
+            res = requests.put(url, data=f, verify=self.__config.get_verify())
             if (res.status_code != 200):
                 raise RuntimeError("Error while trying to upload file: " + res.text)
 
@@ -830,8 +852,10 @@ class Analytics(object):
                 return region["id"]
         raise RuntimeError("Region not found: " + region_code)
 
-    def __run_batch(self, providers, input_id, region_id, all_updates, fixed_list_size):
-        provider_ids = [self.__config.provider_to_version_id(p) for p in providers]
+    def __run_batch(self, input_id, region_id, all_updates, fixed_list_size, providers=None, channel_id=None):
+        if providers:
+            provider_ids = [self.__config.provider_to_version_id(p) for p in providers]
+
         if self.__config.has("API_KEY"):
             username = self.__config.get("API_KEY")[:8]
         else:
@@ -842,12 +866,17 @@ class Analytics(object):
         input = {
             "aegean_batch_run": {
                 "aegean_batch_input_id": input_id,
-                "provider_version_ids": provider_ids,
                 "region_id": region_id,
                 "name": name,
                 "draft": True,
             }
         }
+
+        if providers:
+            input["aegean_batch_run"]["provider_version_ids"] = provider_ids
+        else:
+            input["aegean_batch_run"]["channel_id"] = channel_id
+
         if all_updates is True or all_updates is False:
             input["aegean_batch_run"]["all_updates"] = all_updates
         if fixed_list_size:
@@ -968,9 +997,16 @@ class Analytics(object):
     def __enrich_status_finished(self, resp_json):
         if resp_json["state"] == "pending_approval":
             raise RuntimeError("It looks like you do not have permissions to run live enrichments. Please contact support@demystdata.com for help.")
+
         for provider in resp_json["batch_run_provider_versions"]:
             if not provider["most_recent_export_link"]:
                 return False
+
+        for provider_name, export_link in ((resp_json.get("batch_run_channel") or {}).
+                                                      get("most_recent_export_link_by_provider", {}).items()):
+            if not export_link:
+                return False
+
         return True
 
     # For each provider X, create a message like "X (55%)" or "X
@@ -1022,10 +1058,11 @@ class Analytics(object):
         if block_until_complete:
             self.enrich_wait(id)
         resp_json = self.__config.auth_get(self.__config.get("MANTA_URL") + "aegean_batch_runs/" + str(id)).json()
-        provider_results = resp_json["batch_run_provider_versions"]
-        # Gather all exports
+
         exports = [] # list of { provider_name, export_link, temp_fd, temp_path }
-        for r in provider_results:
+
+        # Gather all exports
+        for r in resp_json["batch_run_provider_versions"]:
             export_link = r["most_recent_export_link"]
             provider_name = r["table_provider"]["name"]
             if export_link:
@@ -1037,9 +1074,22 @@ class Analytics(object):
                                      "temp_path": temp_path })
             else:
                 print("Provider " +provider_name+ " has not finished enrichment and will not be included." , file=sys.stderr)
+
+        for provider_name, export_link in ((resp_json.get("batch_run_channel") or {}).
+                                                      get("most_recent_export_link_by_provider", {}).items()):
+            if export_link:
+                if (len(providers) == 0) or (provider_name in providers):
+                    temp_fd, temp_path = tempfile.mkstemp(prefix=provider_name, suffix=".csv")
+                    exports.append({ "provider_name": provider_name,
+                                     "export_link": export_link,
+                                     "temp_fd": temp_fd,
+                                     "temp_path": temp_path })
+            else:
+                print("Provider " +provider_name+ " has not finished enrichment and will not be included." , file=sys.stderr)
+
         # Download all export links to temp files in parallel
         def fetch_export(export):
-            r = requests.get(export["export_link"], stream=True)
+            r = requests.get(export["export_link"], stream=True, verify=self.__config.get_verify())
             if r.status_code == 200:
                 with open(export["temp_path"], "wb") as f:
                     for chunk in r:
@@ -1100,9 +1150,10 @@ class Analytics(object):
 
     def fetch_export_links(self, id):
         resp_json = self.__config.auth_get(self.__config.get("MANTA_URL") + "aegean_batch_runs/" + str(id)).json()
-        provider_results = resp_json["batch_run_provider_versions"]
+
         exports = [] # list of { provider_name, export_link }
-        for r in provider_results:
+
+        for r in resp_json["batch_run_provider_versions"]:
             export_link = r["most_recent_export_link"]
             provider_name = r["table_provider"]["name"]
             if export_link:
@@ -1110,6 +1161,15 @@ class Analytics(object):
                                  "export_link": export_link })
             else:
                 print("Provider " +provider_name+ " has not finished enrichment and will not be included." , file=sys.stderr)
+
+        for provider_name, export_link in ((resp_json.get("batch_run_channel") or {}).
+                                                      get("most_recent_export_link_by_provider", {}).items()):
+            if export_link:
+                exports.append({ "provider_name": provider_name,
+                                 "export_link": export_link })
+            else:
+                print("Provider " +provider_name+ " has not finished enrichment and will not be included." , file=sys.stderr)
+
         doc = Doc()
         with doc.tag("table"):
             with doc.tag("tr"):
@@ -1312,7 +1372,7 @@ class Analytics(object):
         return balance
 
     HIDE_SETTINGS=["MANTA_URL", "BLACKFIN_URL", "PASSWORD"]
-    
+
     # Print configuration settings
     def show_settings(self):
         for (key, val) in self.__config.settings.items():
@@ -1489,7 +1549,7 @@ class Analytics(object):
         else:
             print("No output fields for " + provider_name)
             return None
-    
+
     def __collect_outputs(self, provider_name, outputs, result, name_prefix):
         for o in outputs:
             name = name_prefix + (o.get("name") or "unknown")
@@ -1533,30 +1593,30 @@ class Analytics(object):
                     results.append({ "provider": provider_name, "attribute": row["attribute"] })
         return pd.DataFrame(results)
 
-    def load_input(self, csv_path_or_df):
-        """Automatically infers the type of input from the CSV file."""
-        from demyst.analytics.type_guesser import TypeGuesser
-        t = TypeGuesser(csv_path_or_df)
-        t.analyze()
-        return(t.data.astype(str))
-
-    def sample_enrich(self, csv_path_or_df):
-        """
-        Performs the task done by load_input(), search(), and
-        enrich_and_download() so you can see a sample response in one
-        step.
-        """
-        def headline(string):
-            display(HTML("<h1>" +  string + "</h1>"))
-        headline("Inferring types...")
-        typed_df = self.load_input(csv_path_or_df)
-        display(typed_df)
-        headline("Searching matching providers...")
-        display(self.search(typed_df, strict=True))
-        providers = self.search(typed_df, strict=True, notebook=False)
-        provider_names = [p["name"] for p in providers]
-        headline("Running sample enrichment...")
-        return self.enrich_and_download(provider_names, typed_df.head(30), validate=False)
+    # def load_input(self, csv_path_or_df):
+    #     """Automatically infers the type of input from the CSV file."""
+    #     from demyst.analytics.type_guesser import TypeGuesser
+    #     t = TypeGuesser(csv_path_or_df)
+    #     t.analyze()
+    #     return(t.data.astype(str))
+    #
+    # def sample_enrich(self, csv_path_or_df):
+    #     """
+    #     Performs the task done by load_input(), search(), and
+    #     enrich_and_download() so you can see a sample response in one
+    #     step.
+    #     """
+    #     def headline(string):
+    #         display(HTML("<h1>" +  string + "</h1>"))
+    #     headline("Inferring types...")
+    #     typed_df = self.load_input(csv_path_or_df)
+    #     display(typed_df)
+    #     headline("Searching matching providers...")
+    #     display(self.search(typed_df, strict=True))
+    #     providers = self.search(typed_df, strict=True, notebook=False)
+    #     provider_names = [p["name"] for p in providers]
+    #     headline("Running sample enrichment...")
+    #     return self.enrich_and_download(provider_names, typed_df.head(30), validate=False)
 
     def sample_data(self, provider_name, row_limit=None, filters=None):
         """Returns sample data for a provider."""
@@ -1651,7 +1711,7 @@ class Analytics(object):
                                  "temp_path": temp_path })
 
             def fetch_chunk(export):
-                req = requests.get(export["export_link"], stream=True)
+                req = requests.get(export["export_link"], stream=True, verify=self.__config.get_verify())
                 if req.status_code == 200:
                     with open(export["temp_path"], "wb") as f:
                         for chunk in req:
@@ -1804,7 +1864,7 @@ class Analytics(object):
         "validation_error": "Re-check the input values. An empty string or a blank space could cause this error.",
         "insufficient_api_key_permissions": "Re-run after authorizing with the right API key",
         }
-    
+
     # Attempts to parse error message and return tuple (type, msg).
     # If it cannot be parsed returns ("other_error", ...) where ... is
     # the whole error message.
@@ -1858,7 +1918,7 @@ class Analytics(object):
         results_df = pd.DataFrame(results)
         results_df = results_df.sort_values(["Provider", "Error Type"]).reset_index()
         return results_df[["Provider", "Error Type", "Error Message", "Count", "Percentage", "Resolution"]]
-    
+
 def show_package_versions():
     installed_packages = pkg_resources.working_set
     for i in installed_packages:
